@@ -12,35 +12,51 @@ from ..utils import check_call, check_output, is_windows
 import subprocess
 
 DOT_ALDRYN_FILE_NOT_FOUND = (
-    "Divio Cloud project file '.aldryn' could not be found!\n"
+    "Divio Cloud configuration file '{}' or '{}' could not be found!\n"
     "Please make sure you're in a Divio Cloud project folder and the "
-    "file exists."
+    "file exists.\n\n"
+    "You can create a new configuration file for an existing project "
+    "with the `divio project configure` command.".format(
+        settings.ALDRYN_DOT_FILE, settings.DIVIO_DOT_FILE
+    )
 )
 
 
-def get_aldryn_project_settings(path=None, silent=False):
+def get_project_settings(path=None, silent=False):
     project_home = get_project_home(path, silent=silent)
     try:
-        with open(os.path.join(project_home, settings.ALDRYN_DOT_FILE)) as fh:
+        if os.path.exists(os.path.join(project_home, settings.ALDRYN_DOT_FILE)):
+            path = os.path.join(project_home, settings.ALDRYN_DOT_FILE)
+        else:
+            path = os.path.join(project_home, settings.DIVIO_DOT_FILE)
+        with open(path) as fh:
             return json.load(fh)
     except (TypeError, OSError):
         raise click.ClickException(DOT_ALDRYN_FILE_NOT_FOUND)
+    except json.decoder.JSONDecodeError:
+        click.secho(f"Error: Unexpected value in {path}", fg="red")
+        sys.exit(1)
 
 
 def get_project_home(path=None, silent=False):
     """
     find project root by traversing up the tree looking for
-    the '.aldryn' file
+    the configuration file
     """
     previous_path = None
     current_path = path or os.getcwd()
+    global_config_path = config.get_global_config_path()
 
     # loop until we're at the root of the volume
     while current_path != previous_path:
-
-        # check if '.aldryn' file exists in current directory
+        # check if configuration file exists in current directory
         dotfile = os.path.join(current_path, settings.ALDRYN_DOT_FILE)
-        if os.path.exists(dotfile) and dotfile != config.CONFIG_FILE_PATH:
+        if os.path.exists(dotfile) and dotfile != global_config_path:
+            return current_path
+
+        # check if configuration file exists in current directory
+        dotfile = os.path.join(current_path, settings.DIVIO_DOT_FILE)
+        if os.path.exists(dotfile) and dotfile != global_config_path:
             return current_path
 
         # traversing up the tree
@@ -62,11 +78,12 @@ def get_docker_compose_cmd(path):
     else:
         docker_compose_filename = UNIX_DOCKER_COMPOSE_FILENAME
 
-    docker_compose_base = [
-        "docker-compose",
-        "-f",
-        os.path.join(path, docker_compose_filename),
-    ]
+    docker_compose_filename = os.path.join(path, docker_compose_filename)
+
+    if not os.path.isfile(docker_compose_filename):
+        raise RuntimeError("Warning: Could not find a 'docker-compose.yml' file.")
+
+    docker_compose_base = ["docker-compose", "-f", docker_compose_filename]
 
     def docker_compose(*commands):
         return docker_compose_base + [cmd for cmd in commands]
@@ -105,9 +122,7 @@ def ensure_windows_docker_compose_file_exists(path):
     unix_path = os.path.join(path, UNIX_DOCKER_COMPOSE_FILENAME)
     if not os.path.isfile(unix_path):
         # TODO: use correct exit from click
-        click.secho(
-            "docker-compose.yml not found at {}".format(unix_path), fg="red"
-        )
+        click.secho("docker-compose.yml not found at {}".format(unix_path), fg="red")
         sys.exit(1)
 
     with open(unix_path, "r") as fh:
@@ -146,15 +161,24 @@ def get_db_container_id(path, raise_on_missing=True, prefix="DEFAULT"):
     """
     Returns the container id for a running database with a given prefix.
     """
-    docker_compose = get_docker_compose_cmd(path)
     try:
-        output = check_output(docker_compose("ps", "-q", "database_{}".format(prefix).lower()), catch=False, stderr=open(os.devnull, "w")).rstrip(os.linesep)
+        docker_compose = get_docker_compose_cmd(path)
+    except RuntimeError:
+        raise exceptions.DivioException(
+            "docker-compose.yml not found. Unable to find database container"
+        )
+    try:
+        output = check_output(
+            docker_compose("ps", "-q", "database_{}".format(prefix).lower()),
+            catch=False,
+            stderr=open(os.devnull, "w"),
+        ).rstrip(os.linesep)
         if not output and raise_on_missing:
-            raise exceptions.AldrynException("Unable to find database container")
+            raise exceptions.DivioException("Unable to find database container")
     except subprocess.CalledProcessError:
         output = check_output(docker_compose("ps", "-q", "db")).rstrip(os.linesep)
         if not output and raise_on_missing:
-            raise exceptions.AldrynException("Unable to find database container")
+            raise exceptions.DivioException("Unable to find database container")
     return output
 
 
@@ -207,12 +231,12 @@ def allow_remote_id_override(func):
         ERROR_MSG = (
             "This command requires a Divio Cloud Project id. Please "
             "provide one with the --remote-id option or call the "
-            "command from a project directory (with a .aldryn file)."
+            "command from a project directory."
         )
 
         if not remote_id:
             try:
-                remote_id = get_aldryn_project_settings(silent=True)["id"]
+                remote_id = get_project_settings(silent=True)["id"]
             except KeyError:
                 raise click.ClickException(ERROR_MSG)
             else:
@@ -227,7 +251,7 @@ def allow_remote_id_override(func):
         type=int,
         help="Remote Project ID to use for project commands. "
         "Defaults to the project in the current directory using the "
-        ".aldryn file.",
+        "configuration file.",
     )(read_remote_id)
 
 
@@ -237,16 +261,27 @@ def get_service_type(identifier, path=None):
     variable of a services from the docker-compose file.
     """
     project_home = get_project_home(path)
-    docker_compose = get_docker_compose_cmd(project_home)
+    try:
+        docker_compose = get_docker_compose_cmd(project_home)
+    except RuntimeError:
+        # Docker-compose does not exist
+        click.secho(
+            "Warning: docker-compose.yml does not exist. Can not get the service type without!",
+            fg="red",
+        )
+        sys.exit(1)
     docker_compose_config = DockerComposeConfig(docker_compose)
     services = docker_compose_config.get_services()
-    if identifier in services and "environment" in services[identifier] and "SERVICE_MANAGER" in services[identifier]["environment"]:
+    if (
+        identifier in services
+        and "environment" in services[identifier]
+        and "SERVICE_MANAGER" in services[identifier]["environment"]
+    ):
         return services[identifier]["environment"]["SERVICE_MANAGER"]
 
     raise RuntimeError("Can not get service type")
 
 
-
 def get_db_type(prefix, path=None):
     """
     Utility function to wrap `get_service_type` to search for databases so we
@@ -256,7 +291,15 @@ def get_db_type(prefix, path=None):
         db_type = get_service_type("database_{}".format(prefix.lower()), path=path)
     except RuntimeError:
         # legacy section. we try to look for the db, if it does not exist, fail
-        docker_compose = get_docker_compose_cmd(path)
+        try:
+            docker_compose = get_docker_compose_cmd(path)
+        except RuntimeError:
+            # Docker-compose does not exist
+            click.secho(
+                "Warning: docker-compose.yml does not exist. Can not get the service type without!",
+                fg="red",
+            )
+            sys.exit(1)
         docker_compose_config = DockerComposeConfig(docker_compose)
         if not docker_compose_config.has_service("db"):
             click.secho('No service "db" found in local project', fg="red")
