@@ -3,6 +3,7 @@ import pytest
 import click
 
 from divio_cli.localdev import utils
+from divio_cli import settings
 
 
 def test_get_project_home(tmp_path):
@@ -15,7 +16,7 @@ def test_get_project_home(tmp_path):
     home = utils.get_project_home(str(tmp_path), silent=True)
     assert not home
 
-    p = tmp_path / ".aldryn"
+    p = tmp_path / settings.ALDRYN_DOT_FILE
     p.write_text(u"#Examplecontent")
     home = utils.get_project_home(str(tmp_path))
     assert home
