@@ -17,23 +17,21 @@ def get_license(path):
 def load_config(fname, path=None):
     config_fpath = os.path.join(path or ".", fname)
     if not os.path.exists(config_fpath):
-        raise exceptions.AldrynException(
-            messages.FILE_NOT_FOUND.format(config_fpath)
-        )
+        raise exceptions.DivioException(messages.FILE_NOT_FOUND.format(config_fpath))
 
     with open(config_fpath) as f:
         try:
             return json.load(f)
         except ValueError:
-            raise exceptions.AldrynException(
+            raise exceptions.DivioException(
                 "Config file could not be loaded: Invalid JSON"
             )
 
 
-def validate_package_config(config, required_keys, config_path):
+def validate_package_config(config, required_keys, path):
     errors = []
 
-    if not get_license(config_path):
+    if not get_license(path):
         errors.append(
             "Required LICENSE file not found. Valid names are {}.".format(
                 ", ".join(VALID_LICENSE_FILENAMES)
@@ -42,8 +40,6 @@ def validate_package_config(config, required_keys, config_path):
 
     for key in required_keys:
         if key not in config:
-            errors.append(
-                'Required key "{}" not found in config file.'.format(key)
-            )
+            errors.append('Required key "{}" not found in config file.'.format(key))
 
     return errors
